@@ -17,9 +17,9 @@ def represent_and_encode(obj):
 
 
 def make_hashable(obj):
-	try:
+	if hasattr(obj, '__hashkey__'):
 		return make_hashable(obj.__hashkey__())
-	except AttributeError:
+	else:
 		if isinstance(obj, (tuple, list)):
 			return tuple((make_hashable(e) for e in obj))
 
